const puppeteer = require("puppeteer");
const Server = require("ws").Server;
const args = require("yargs")
    .usage("Usage : import_content.js -file file_path " +
    "-u if uncompressed file -b for bulk")
    .demandOption(["file"])
    .alias("f", "file")
    .alias("u", "uncompressed")
    .alias("b", "bulk")
    .describe("file", "file containing the index")
    .describe("uncompressed", "to add if file is uncompressed ! For testing only !")
    .describe("bulk", "adds items to db in bulk. Much faster but still in testing")
    .nargs("file", 1)
    .nargs("u", 0)
    .nargs("b", 0)
    .alias("l", "link")
    .describe("link", "link to website treating the data, defaults to Mynij")
    .nargs("link", 1)
    .argv;

var link;

if (args.link == null) {
    link ="https://softinst115787.host.vifib.net/public/unit_tests/";
    if (args.uncompressed) {
        link +=  "import_content_uncompressed.html";
    } else if (args.bulk) {
        link += "import_content_bulk.html";
    } else {
        link += "import_content.html";
    }
} else {
    link = args.link;
}

var browser;
var start;

function init_server (){
    var port = 9030;
    var ws = new Server({port: port});
    ws.on("connection", function(w){
        w.on("message", function(msg){
            if (msg.includes("Done")){
                var time_spent = Date.now() - start;
                process.send(time_spent/1000);
                process.send("DONE");
                browser.close();
                ws.close();
            } else {
                console.log("Error : " + msg);
                browser.close();
                ws.close();
            }
        });
        w.on("close", function() {
            ws.close();
        });
    });
}

(async () => {
    init_server();
    browser = await puppeteer.launch();
    var page = await browser.newPage();
    await page.goto(link);
    start = Date.now();
    const [fileChooser] = await Promise.all([
        page.waitForFileChooser(),
        page.click("input#load")
    ]);
    await fileChooser.accept([args.file]);
})();
